#include <err.h>
#include <stdlib.h>
#include <stdint.h>
#include <fcntl.h>
#include <stdio.h>
#include <stdbool.h>
#include <string.h>
#include <ctype.h>
#include <sys/mman.h>
#include <sys/ioctl.h>

#define __packed __attribute__((packed))

#define SYSCHK(x) ({          \
  typeof(x) __res = (x);      \
  if (__res == (typeof(x))-1) \
    err(1, "SYSCHK(" #x ")"); \
  __res;                      \
})

struct drm_pvr_srvkm_cmd {
  uint32_t bridge_id;
  uint32_t bridge_func_id;
  uint64_t in_data_ptr;
  uint64_t out_data_ptr;
  uint32_t in_data_size;
  uint32_t out_data_size;
};
#define DRM_IOCTL_PVR_SRVKM_CMD 0xc0206440

static int gpu_fd;
static int driver_cmd(int bridge_id, int bridge_func_id, void *in_data, void *out_data, int in_size, int out_size) {
  struct drm_pvr_srvkm_cmd cmd = {
    .bridge_id = bridge_id,
    .bridge_func_id = bridge_func_id,
    .in_data_ptr = (unsigned long)in_data,
    .out_data_ptr = (unsigned long)out_data,
    .in_data_size = in_size,
    .out_data_size = out_size
  };
  return ioctl(gpu_fd, DRM_IOCTL_PVR_SRVKM_CMD, &cmd);
}
#define do_driver_cmd_noerror(bridge_id, bridge_func_id) ({                                \
    SYSCHK(driver_cmd((bridge_id), (bridge_func_id), &in, &out, sizeof(in), sizeof(out))); \
})
#define do_driver_cmd(bridge_id, bridge_func_id) ({                                        \
    do_driver_cmd_noerror((bridge_id), (bridge_func_id));                                  \
    if (out.eError != 0) errx(1, #bridge_func_id " eError %u", out.eError);                \
})
#define do_driver_cmd_ignore(bridge_id, bridge_func_id) ({                                        \
    do_driver_cmd_noerror((bridge_id), (bridge_func_id));                                  \
    if (out.eError != 0) printf(#bridge_func_id " eError %u\n", out.eError);                \
})

typedef void *IMG_HANDLE;

#define PVRSRV_BRIDGE_MM 6
#define PVRSRV_BRIDGE_MM_DEVMEMINTRESERVERANGE 21
typedef struct PVRSRV_BRIDGE_IN_DEVMEMINTRESERVERANGE_TAG
{
	uint64_t sAddress;
	uint64_t uiLength;
	IMG_HANDLE hDevmemServerHeap;
} __packed PVRSRV_BRIDGE_IN_DEVMEMINTRESERVERANGE;
typedef struct PVRSRV_BRIDGE_OUT_DEVMEMINTRESERVERANGE_TAG
{
	IMG_HANDLE hReservation;
	int eError;
} __packed PVRSRV_BRIDGE_OUT_DEVMEMINTRESERVERANGE;
#define PVRSRV_BRIDGE_MM_DEVMEMINTHEAPCREATE 17
typedef struct PVRSRV_BRIDGE_IN_DEVMEMINTHEAPCREATE_TAG
{
	uint64_t sHeapBaseAddr; //ignored
	uint64_t uiHeapLength; //ignored
	IMG_HANDLE hDevmemCtx;
	uint32_t ui32Log2DataPageSize;
} __packed PVRSRV_BRIDGE_IN_DEVMEMINTHEAPCREATE;
typedef struct PVRSRV_BRIDGE_OUT_DEVMEMINTHEAPCREATE_TAG
{
	IMG_HANDLE hDevmemHeapPtr;
	int eError;
} __packed PVRSRV_BRIDGE_OUT_DEVMEMINTHEAPCREATE;
#define PVRSRV_BRIDGE_MM_DEVMEMINTCTXCREATE 15
typedef struct PVRSRV_BRIDGE_IN_DEVMEMINTCTXCREATE_TAG
{
	int bbKernelMemoryCtx;
} __packed PVRSRV_BRIDGE_IN_DEVMEMINTCTXCREATE;
typedef struct PVRSRV_BRIDGE_OUT_DEVMEMINTCTXCREATE_TAG
{
	IMG_HANDLE hDevMemServerContext;
	IMG_HANDLE hPrivData;
	int eError;
	unsigned int ui32CPUCacheLineSize;
} __packed PVRSRV_BRIDGE_OUT_DEVMEMINTCTXCREATE;
#define PVRSRV_BRIDGE_MM_PHYSMEMNEWRAMBACKEDLOCKEDPMR 10
typedef struct PVRSRV_BRIDGE_IN_PHYSMEMNEWRAMBACKEDLOCKEDPMR_TAG
{
	uint64_t uiChunkSize;
	uint64_t uiSize;
	uint32_t *pui32MappingTable;
	const char *puiAnnotation;
	uint32_t ui32AnnotationLength;
	uint32_t ui32Log2PageSize;
	uint32_t ui32NumPhysChunks;
	uint32_t ui32NumVirtChunks;
	uint32_t ui32PDumpFlags;
	uint32_t ui32PID;
	uint64_t uiFlags;
} __packed PVRSRV_BRIDGE_IN_PHYSMEMNEWRAMBACKEDLOCKEDPMR;
typedef struct PVRSRV_BRIDGE_OUT_PHYSMEMNEWRAMBACKEDLOCKEDPMR_TAG
{
	IMG_HANDLE hPMRPtr;
	int eError;
} __packed PVRSRV_BRIDGE_OUT_PHYSMEMNEWRAMBACKEDLOCKEDPMR;

#define PVRSRV_BRIDGE_MM_DEVMEMINTMAPPMR 19
typedef struct PVRSRV_BRIDGE_IN_DEVMEMINTMAPPMR_TAG
{
	IMG_HANDLE hDevmemServerHeap;
	IMG_HANDLE hPMR;
	IMG_HANDLE hReservation;
	uint64_t uiMapFlags;
} __packed PVRSRV_BRIDGE_IN_DEVMEMINTMAPPMR;
typedef struct PVRSRV_BRIDGE_OUT_DEVMEMINTMAPPMR_TAG
{
	IMG_HANDLE hMapping;
	int eError;
} __packed PVRSRV_BRIDGE_OUT_DEVMEMINTMAPPMR;

static IMG_HANDLE create_device_memory_context(void) {
  PVRSRV_BRIDGE_IN_DEVMEMINTCTXCREATE in = { .bbKernelMemoryCtx = false };
  PVRSRV_BRIDGE_OUT_DEVMEMINTCTXCREATE out = {};
  do_driver_cmd(PVRSRV_BRIDGE_MM, PVRSRV_BRIDGE_MM_DEVMEMINTCTXCREATE);
  printf("cache line: %u bytes\n", out.ui32CPUCacheLineSize);
  // TODO ignoring private data subhandle
  return out.hDevMemServerContext;
}

static IMG_HANDLE create_heap(IMG_HANDLE mem_ctx, unsigned int page_size_log2) {
  PVRSRV_BRIDGE_IN_DEVMEMINTHEAPCREATE in = {
    .hDevmemCtx = mem_ctx,
    .ui32Log2DataPageSize = page_size_log2
  };
  PVRSRV_BRIDGE_OUT_DEVMEMINTHEAPCREATE out = {};
  do_driver_cmd(PVRSRV_BRIDGE_MM, PVRSRV_BRIDGE_MM_DEVMEMINTHEAPCREATE);
  return out.hDevmemHeapPtr;
}

static IMG_HANDLE create_reservation(IMG_HANDLE heap, uint64_t base, uint64_t len) {
  PVRSRV_BRIDGE_IN_DEVMEMINTRESERVERANGE in = {
    .sAddress = base, .uiLength = len, .hDevmemServerHeap = heap
  };
  PVRSRV_BRIDGE_OUT_DEVMEMINTRESERVERANGE out = {};
  do_driver_cmd(PVRSRV_BRIDGE_MM, PVRSRV_BRIDGE_MM_DEVMEMINTRESERVERANGE);
  return out.hReservation;
}

#define PAGE_ORDER_4K (12)
#define PAGE_ORDER_1M (12+8)
#define PAGE_ORDER_2M (12+9)

// non-sparse, locked
static IMG_HANDLE alloc_pmr(uint64_t alloc_size, int page_size) {
  uint32_t mapping_table[1] = { 0 }; // virtual chunk idx by physical chunk idx ?
  uint64_t heap_idx = 1; // cpu-local
  uint64_t cpu_cache_mode = 2; // cache-coherent with snoop if supported
  uint64_t gpu_cache_mode = 2; // cache-coherent with snoop if supported
  PVRSRV_BRIDGE_IN_PHYSMEMNEWRAMBACKEDLOCKEDPMR in = {
    .uiChunkSize = alloc_size,
    .uiSize = alloc_size,
    .pui32MappingTable = mapping_table,
    .puiAnnotation = "foobar",
    .ui32AnnotationLength = 7,
    .ui32Log2PageSize = page_size,
    .ui32NumPhysChunks = 1, // ?
    .ui32NumVirtChunks = 1,
    .ui32PDumpFlags = 0,
    .ui32PID = 0,
    .uiFlags = 0xf/*GPU RW, remap ok*/ | 0xf0/*CPU RW, remap ok*/ | (gpu_cache_mode << 8) | (cpu_cache_mode << 11) |
               (/*kernel-mappable*/0<<14) | (/*on-demand*/0<<15) | (/*SVM*/0<<17) |
               (/*sparse no dummy*/0<<18) | (/*cache clean (why is this even a question)*/1<<19) |
               (/*zero backing*/0<<20) | (/*zero on alloc WTF why even ask XXX*/0ULL<<31) | (heap_idx << 59)
  };
  PVRSRV_BRIDGE_OUT_PHYSMEMNEWRAMBACKEDLOCKEDPMR out = {};
  do_driver_cmd(PVRSRV_BRIDGE_MM, PVRSRV_BRIDGE_MM_PHYSMEMNEWRAMBACKEDLOCKEDPMR);
  return out.hPMRPtr;
}

static void map_pmr(IMG_HANDLE heap, IMG_HANDLE resv, IMG_HANDLE pmr) {
  uint64_t heap_idx = 1; // cpu-local
  uint64_t cpu_cache_mode = 2; // cache-coherent with snoop if supported
  uint64_t gpu_cache_mode = 2; // cache-coherent with snoop if supported
  PVRSRV_BRIDGE_IN_DEVMEMINTMAPPMR in = {
    .hDevmemServerHeap = heap,
    .hPMR = pmr,
    .hReservation = resv,
    .uiMapFlags = 0xf/*GPU RW, remap ok*/ | 0xf0/*CPU RW, remap ok*/ | (gpu_cache_mode << 8) | (cpu_cache_mode << 11) |
               (/*kernel-mappable*/0<<14) | (/*on-demand*/0<<15) | (/*SVM*/0<<17) |
               (/*sparse no dummy*/0<<18) | (/*cache clean (why is this even a question)*/1<<19) |
               (/*zero backing*/0<<20) | (/*zero on alloc, ignored by driver*/0ULL<<31) | (heap_idx << 59)
  };
  PVRSRV_BRIDGE_OUT_DEVMEMINTMAPPMR out;
  do_driver_cmd_ignore(PVRSRV_BRIDGE_MM, PVRSRV_BRIDGE_MM_DEVMEMINTMAPPMR);
}

int main(void) {
  setbuf(stdout, NULL);
  gpu_fd = SYSCHK(open("/dev/dri/renderD128", O_RDWR));

  IMG_HANDLE mem_ctx = create_device_memory_context();
  IMG_HANDLE heap_4k = create_heap(mem_ctx, 12);
  IMG_HANDLE heap_1m = create_heap(mem_ctx, 12+8);

  IMG_HANDLE pmr_1m_4k = alloc_pmr(1<<PAGE_ORDER_1M, PAGE_ORDER_4K);
  //IMG_HANDLE pmr_1m_1m = alloc_pmr(1<<PAGE_ORDER_1M, PAGE_ORDER_1M);
  for (int i=0; i<100000; i++) {
    printf("iter %d\n", i);
    uint64_t base = i * (1ULL << PAGE_ORDER_2M);
    printf("resv 1m\n");
    IMG_HANDLE resv_1m = create_reservation(heap_1m, base, 1<<PAGE_ORDER_1M);
    printf("resv 4k\n");
    IMG_HANDLE resv_4k = create_reservation(heap_4k, base + (1<<PAGE_ORDER_1M), 1<<PAGE_ORDER_1M);
    printf("map\n");
    map_pmr(heap_4k, resv_4k, pmr_1m_4k);
  }
  printf("survived?\n");
}
